+++
title = "Title with lots of ` ` ` backticks` * asterisks bold, italics retain*,_,` in monospace underscores _ _ foo bar **"
tags = ["title"]
draft = false
+++

-   All the Org markup characters are removed.
-   The "markup characters" not doing actual markup are retained.
